@@ -75,7 +75,7 @@ def index():
     if request.method == 'POST':
         # print_request_values(request.form.values())
         post_request = request.form.to_dict()  # flat dict werkzeug doc
-
+        # print(post_request)
         json_post = index_posts_clicked(post_request)
         return json_post
 
@@ -112,10 +112,10 @@ def index_posts_clicked(post_request):
     global last_btn_id
     global listen_last_url
 
-    pay_load = post_request['data']
-    button_list = pay_load.split('_')
+    button_list = post_request['name'].split('_')
     table_id = button_list[1]
     button = button_list[0]
+    current_station = ''
 
     if button == 'Listen':  # turn values, update button status dict
 
@@ -123,7 +123,7 @@ def index_posts_clicked(post_request):
             status_listen_btn_dict[int(table_id)] = 0
             EisenApp.dispatch_master(int(table_id), 'Listen', 0)
             if not last_btn_id == table_id:
-                return jsonify({'result': 'auto_click was here. no result needed. nada'})
+                return jsonify({'result': 'auto_click, no_audio_action', 'table_ident': current_station, 'radio_table_id': table_id, 'class_val': post_request['class_val']})
         else:
             status_listen_btn_dict[int(table_id)] = 1   # button just pressed, register state, new station
 
@@ -139,7 +139,7 @@ def index_posts_clicked(post_request):
                         {'former_button_to_switch': switch_btn,
                          'query_url': listen_last_url,
                          'if not last_btn_id == table_id': '------ last_btn_id --------',
-                         'result': 'activate_audio', 'table_ident': current_station})
+                         'result': 'activate_audio', 'table_ident': current_station, 'radio_table_id': table_id, 'class_val': post_request['class_val']})
 
             EisenApp.dispatch_master(int(table_id), 'Listen', 1)
 
@@ -156,12 +156,12 @@ def index_posts_clicked(post_request):
         if listen_btn:
             current_station = status_read_status_set(False, 'posts', 'title', table_id)
             return jsonify(
-                {'former_button_to_switch': False, 'buttons': button, 'query_url': listen_last_url,
-                 'result': 'activate_audio', 'table_ident': current_station})
+                {'result': 'activate_audio', 'former_button_to_switch': False, 'buttons': button, 'query_url': listen_last_url,
+                 'table_ident': current_station, 'radio_table_id': table_id, 'class_val': post_request['class_val']})
         else:
             return jsonify(
-                {'former_button_to_switch': False, 'buttons': button, 'query_url': listen_last_url,
-                 'result': 'deactivate_audio'})
+                {'result': 'deactivate_audio', 'former_button_to_switch': False, 'buttons': button, 'query_url': listen_last_url,
+                 'table_ident': current_station, 'radio_table_id': table_id, 'class_val': post_request['class_val']})
 
     if button == 'Record':
         if status_record_btn_dict[int(table_id)]:
@@ -172,7 +172,8 @@ def index_posts_clicked(post_request):
             EisenApp.dispatch_master(int(table_id), 'Record', 1)
 
     # print(f' ---- index_posts_type_ajax {button + "_" + table_id}"')
-    return jsonify({'buttons': button})
+    return jsonify({'result': 'no_audio_result','buttons': button, 'former_button_to_switch': False, 'query_url': listen_last_url, 
+					'radio_table_id': table_id, 'class_val': post_request['class_val']})
 
 
 def query_radio_url(table_id):
@@ -723,7 +724,7 @@ def get_environment():
     global snap_db_path
     try:
         if os.environ["SNAP"]:
-            print('Eisen App runs in Ubuntu Snap Container, check environment:')
+            print('Eisenradio App runs in Ubuntu Snap Container, check environment:')
             print('')
             print('SNAP_USER_COMMON (your Database lives here, backup if you like): ' + os.environ["SNAP_USER_COMMON"])
             print('SNAP_LIBRARY_PATH: ' + os.environ["SNAP_LIBRARY_PATH"])
@@ -796,4 +797,4 @@ class Radio:
         self.this_radio_id = this_radio_id
 if __name__ == "__main__":
     main()
-    app.run(host='localhost', port='5050', threaded=True, debug=True, use_reloader=False)
+    app.run(host='localhost', port='5050', threaded=True, debug=False, use_reloader=False)
