@@ -42,7 +42,7 @@ import urllib3
 # logging.basicConfig(level=logging.DEBUG, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 # logging.basicConfig(level=logging.INFO, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 
-version = '0.8.0'
+version = '0.8.2'
 print(f'{version} ghettorecorder (eisen_radio module)')  # ########## version #############
 
 class GBase:
@@ -508,7 +508,10 @@ class GRecorder:
 
                 else:
                     try:
-                        GRecorder.current_song_dict[key] = title
+                        if title[0] == "'" and title[-1] == "'":
+                            GRecorder.current_song_dict[key] = title[1:-1]
+                        else:
+                            GRecorder.current_song_dict[key] = title
                         # print(f' -> {key} + {GRecorder.current_song_dict[key]}')
                     except KeyError:
                         pass
