@@ -10,57 +10,70 @@ $(document).ready(function(){
         return;
         };
 
-        clicked = $(this).attr("name");
-        console.log(clicked)
-        class_val = $(this).attr("class");
-        id = $(this).attr("id");
+        let clicked = $(this).attr("name");
+        console.log("send name "+clicked)
+        let class_val = $(this).attr("class");  /* does not survive the request, this is strange */
+        console.log("send button "+class_val)
+        let id = $(this).attr("id");
 
+		let dict = {
+			'name': clicked, 
+			'class_val': class_val,   /* pass it to server and get it back*/
+			'button_id': id, 
+		};
         req = $.ajax({
                 type : 'POST',
-                type : 'POST',
+                dataType : "json",
                 url : "/",
-                data : {'data':clicked}
+                data : dict,
         });
         $('#'+id).fadeOut(1).fadeIn(3);
 
         req.done(function(data) {
-             // console.log(data);
-              console.log(data.result);
-              //console.log(data.button);
-
-             if (class_val == 'btn-primary') {
-                $('#'+id).addClass('btn btn-danger');
-                $('#'+id).removeClass('btn-primary');
+/*
+			  console.log("req.done result "+data.result);
+			  console.log("req.done former_button_to_switch "+data.former_button_to_switch);
+              console.log("req.done button "+data.class_val);
+			  console.log("req.done current_station "+data.current_station);
+			  console.log("req.done buttons (return from index_posts_clicked) "+data.buttons);
+*/
+            if (data.class_val == "btn btn-primary") {
+                        $('#'+id).removeClass("btn btn-primary");
+                        $('#'+id).addClass("btn btn-danger");
             };
 
-            if (class_val == 'btn btn-primary') {
-                        $('#'+id).addClass('btn btn-danger');
-                        $('#'+id).removeClass('btn btn-primary');
+            if (data.class_val == "btn btn-danger") {
+                        $('#'+id).removeClass("btn btn-danger");
+                        $('#'+id).addClass("btn btn-primary");
             };
 
-            if (class_val == 'btn-danger') {
-                        $('#'+id).addClass('btn btn-primary');
-                        $('#'+id).removeClass('btn-danger');
-            };
+            if (data.radio_table_id) {
 
-            if (class_val == 'btn btn-danger') {
-                        $('#'+id).addClass('btn btn-primary');
-                        $('#'+id).removeClass('btn btn-danger');
-            };
-
-            if (data.former_button_to_switch) {
-
-                        var num = data.former_button_to_switch
-                        console.log('auto_click '+num)
-                        $("#"+num).click(); // Click on the button
+                        var r_table_id = data.radio_table_id
             };
             if (data.table_ident) {
                         var current_station = data.table_ident
                         console.log('table_ident '+current_station)
                         
                         if (current_station != 'Null') {
-                        document.getElementById('lbl_div_audio').innerText = current_station;
+						var radioLocation = 'http://localhost:5050/#'+current_station
+						/* document.getElementById("lbl_div_audio").setAttribute('onclick', 'window.location.href=\'http://localhost:5050/body_color_select_all''); */
+                        document.getElementById('lbl_div_audio').innerText = " > " + current_station;
+                        document.getElementById('lbl_div_audio').style.color = "#cccccc";
+						
+						/*document.getElementById('progress_record_all').scrollIntoView();*/
+						/* document.getElementById("lbl_div_audio").setAttribute('onclick', document.getElementById("progress_record_all").scrollIntoView(true)); */
+						/* function ok = document.getElementById("lbl_div_audio").setAttribute('onclick', "window.location='" + "//www.google.de'"); */
+						$("#lbl_div_audio").on('click', function(){
+							/* window.location.href = "http://localhost:5050/#";    */
+							location.hash = "#" + r_table_id;
+							});
                         }
+            if (data.former_button_to_switch) {
+                        var num = data.former_button_to_switch
+                        console.log('auto_click former_button_to_switch: '+num)
+                        $("#"+num).click(); // Click on the button -> $("button").click(function(){ recall, should be last entry in fkt?
+            };
             };
 
                 if (data.result == 'deactivate_audio') {
@@ -72,6 +85,8 @@ $(document).ready(function(){
                         myAudio.src = "";
                         myAudio.load();
                         document.getElementById('lbl_div_audio').innerText  = '*';
+						document.getElementById('lbl_div_audio').style.color = "#f1f1f1";
+
                 };
 
                 if (data.result == 'activate_audio') {
